@@ -46,11 +46,13 @@
 
 
 /*
-Cephes Math Library Release 2.0:  April, 1987
-Copyright 1984, 1987, 1995 by Stephen L. Moshier
+Cephes Math Library Release 2.8:  June, 2000
+Copyright 1984, 1987, 1995, 2000 by Stephen L. Moshier
 */
-
-#ifndef ANSIPROT
+#include "mconf.h"
+#ifdef ANSIPROT
+extern double incbet ( double, double, double );
+#else
 double incbet();
 #endif
 
