@@ -13,6 +13,7 @@
  */
 
 /*							cpmul	*/
+#include "mconf.h"
 
 #ifdef ANSIPROT
 extern void * malloc (long);
@@ -22,12 +23,6 @@ void * malloc();
 void free ();
 #endif
 
-typedef struct
-	{
-	double r;
-	double i;
-	}cmplx;
-
 int 
 cpmul_wrap( ar, ai, da, br, bi, db, cr, ci, dc )
      double *ar, *ai, *br, *bi, *cr, *ci;
